function [eigenvalues, E] = calculateEOF(Y)

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculation of EOFs from a given data matrix Y. The data matrix Y has
% to be centered.
% --Input--
%   Y               matrix containing the time series of gridded data sets 
%                   (n x p)
%
% --Output--
%   eigenvalues     vector containing the p non-zero eigenvalues of the 
%                   covariance matrix C, sorted according to decreasing 
%                   size (p x 1)
%   E               matrix containing in its columns the eigenvectors
%                   (EOFs) of the covariance matrix C. EOFs are sorted 
%                   according to size of corresponding eigenvalue (n x p).

%
% Author: Anne Springer
% Date:  2020-09-16
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Calculate Covariance Matrix (without considering the factor 1/n)
C = Y'*Y;

% calculate matrix of eigenvectors E and eigenvalues lambda
[E, lambda] = eig(C);
lambda = diag(lambda);

% Sort eigenvalues and eigenvectors according to the size of the
% eigenvalues (-eigvalue, because of the missing 1/n computing Sigma)
[sortEig, index] = sort(-lambda);
lambda = lambda(index);
E = E(:, index);

% Calculate eigenvectors of Y*Y'
E = Y*E;

% Normalize eigenvectors => EOFs
E = E*diag(1./(sum(E.^2).^0.5));

% eigenvalues
eigenvalues = lambda;



end