%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Computation of a catchment averaged time series for a given polygon
%
% --Input--
%   data            Matrix containing the data values (n x m x p)
%   lon             longitude values of the grid points (n x 1)
%   lat             latitude values of the grid points (m x 1)
%   polygon         lon and lat of polygon (bx2)
%
% --Output--
%   twsa            catchment averaged time series (p x 1)
%
% Author: Anne Springer
% Date:  2020-09-16
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [twsa] = catchmentAverage(data, lon, lat, polygon)

%% Regular grid
[Lon,Lat] = meshgrid(lon,lat(end:-1:1));

%% Get values inside polygon
IN = inpolygon(Lon,Lat,polygon(:,1),polygon(:,2));

%% Compute area
dLambda = (lon(2)-lon(1))*pi/180;
dPhi = (lat(2)-lat(1))*pi/180;
phi = Lat(IN)*pi/180;
areaVec = dLambda * 2.0 * sin(dPhi/2.0) * cos(phi);

%% Compute catchment average
twsa = NaN(size(data,3),1);
for i = 1:size(data,3)
    temp = data(:,:,i);
    twsa(i,1) = sum(temp(IN).*areaVec)/sum(areaVec);
end


end