%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Visualization of time series
%
% --Input--
%   data            struct containing the time and data values
%                   {[years1,months1,data1],[years2,months2,data2],...}
%   ylim            lower and upper limit of the y-axis (2 x 1)
%   legendStrings   legend entries {'entry1', 'entry2'}
%   titleString     string with title
%   ylabelString    string with label of the y-axis
%
% --Output--
%  Plot of the time series
%
% Author: Anne Springer
% Date:  2020-09-16
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function showTimeseries(data, ylim, legendStrings, titleString, ylabelString)

screensize = get(0,'ScreenSize');
fs = 16; % Fontsize
ms = 15; % MarkerSize
lw = 2;  % LineWidth
figure('Position',[screensize(1)/1,screensize(2)/1,screensize(3)/1.5,(screensize(4)-50)/3]);
set(gca,'FontSize',fs);
set(gca,'YLim',ylim);
hold on
min_t = 99999999;
max_t = -99999999;
for i = 1:length(data)
    % Deal with missing points in time
    startTime = data{i}(1,1:2);
    endTime = data{i}(end,1:2);
    years = repmat(startTime(1):endTime(1),12,1);
    years = years(:);
    months = repmat(1:12,length(unique(years)),1)';
    months = months(:);
    t_all = datenum([years, months, 1*ones(size(years,1),1)]);
    idx = t_all>=datenum([startTime(1), startTime(2), 1]) & t_all<=datenum([endTime(1), endTime(2), 1]);
    t_all = t_all(idx);
    
    % Time for plot
    if min(t_all)<min_t
        min_t = min(t_all);
    end
    if max(t_all)>max_t
        max_t = max(t_all);
    end
    
    % Matlab time
    t = datenum([data{i}(:,1), data{i}(:,2), 1*ones(size(data{i},1),1)]);
    
    % Missing data = NaN
    data_all = NaN(length(t_all),1);
    idx = ismember(t_all,t);
    data_all(idx) = data{i}(:,3);
    
    % Plot time series
    plot(t_all, data_all,'.-','MarkerSize',ms,'LineWidth',lw);
end


% Time for labels
y1 = datevec(min_t); y1 = y1(1);
y2 = datevec(max_t); y2 = y2(1)+1;
years = (y1:y2)';
t_plot = datenum([years, ones(length(years),1), ones(length(years),1)]);
t_plot = [t_plot(1:2:end); t_plot(end)];
t_plot = unique(t_plot);

ylabel(ylabelString)
% ylabel('EWH [mm]')
set(gca,'XTick',t_plot)
datetick('x','mm/yy','keepticks');

legend(legendStrings,'Location','EastOutside')
title(titleString)
